@@ -34,7 +34,7 @@
 #include <QDialog>
 #include "ui_confirmdeletiondlg.h"
 #include "preferences.h"
-#include "misc.h"
+#include "iconprovider.h"
 
 class DeletionConfirmationDlg : public QDialog, private Ui::confirmDeletionDlg {
   Q_OBJECT
@@ -42,8 +42,13 @@ class DeletionConfirmationDlg : public QDialog, private Ui::confirmDeletionDlg {
   public:
   DeletionConfirmationDlg(QWidget *parent=0): QDialog(parent) {
     setupUi(this);
+    // Icons
+    lbl_warn->setPixmap(IconProvider::instance()->getIcon("dialog-warning").pixmap(lbl_warn->height()));
+    lbl_warn->setFixedWidth(lbl_warn->height());
+    rememberBtn->setIcon(IconProvider::instance()->getIcon("object-locked"));
+
     move(misc::screenCenter(this));
-    checkPermDelete->setChecked(Preferences::deleteTorrentFilesAsDefault());
+    checkPermDelete->setChecked(Preferences().deleteTorrentFilesAsDefault());
     connect(checkPermDelete, SIGNAL(clicked()), this, SLOT(updateRememberButtonState()));
     buttonBox->setFocus();
   }
@@ -63,11 +68,11 @@ class DeletionConfirmationDlg : public QDialog, private Ui::confirmDeletionDlg {
 
 private slots:
   void updateRememberButtonState() {
-    rememberBtn->setEnabled(checkPermDelete->isChecked() != Preferences::deleteTorrentFilesAsDefault());
+    rememberBtn->setEnabled(checkPermDelete->isChecked() != Preferences().deleteTorrentFilesAsDefault());
   }
 
   void on_rememberBtn_clicked() {
-    Preferences::setDeleteTorrentFilesAsDefault(checkPermDelete->isChecked());
+    Preferences().setDeleteTorrentFilesAsDefault(checkPermDelete->isChecked());
     rememberBtn->setEnabled(false);
   }
 };
