@@ -31,6 +31,9 @@
 #ifndef MISC_H
 #define MISC_H
 
+#include <libtorrent/version.hpp>
+#include <libtorrent/torrent_info.hpp>
+#include <libtorrent/torrent_handle.hpp>
 #include <sstream>
 #include <QString>
 #include <QStringList>
@@ -45,9 +48,6 @@
 #include <QIcon>
 #endif
 
-#include <libtorrent/torrent_info.hpp>
-#include <libtorrent/torrent_handle.hpp>
-
 const qlonglong MAX_ETA = 8640000;
 
 /*  Miscellaneaous functions that can be useful */
@@ -81,7 +81,7 @@ public:
   }
 
   static inline libtorrent::sha1_hash toSha1Hash(const QString &hash) {
-    return libtorrent::sha1_hash(qPrintable(hash));
+    return libtorrent::sha1_hash(hash.toAscii().constData());
   }
 
   static void chmod644(const QDir& folder);
@@ -104,8 +104,9 @@ public:
 
   static inline QString file_extension(const QString &filename) {
     QString extension;
-    if(filename.contains(".")) {
-      extension = filename.mid(filename.lastIndexOf(".")+1);
+    int point_index = filename.lastIndexOf(".");
+    if(point_index >= 0) {
+      extension = filename.mid(point_index+1);
     }
     return extension;
   }
