@@ -62,7 +62,6 @@ using namespace libtorrent;
 PropertiesWidget::PropertiesWidget(QWidget *parent, MainWindow* main_window, TransferListWidget *transferList):
   QWidget(parent), transferList(transferList), main_window(main_window) {
   setupUi(this);
-  loadFilesListState();
 
   // Icons
   deleteWS_button->setIcon(IconProvider::instance()->getIcon("list-remove"));
@@ -107,13 +106,8 @@ PropertiesWidget::PropertiesWidget(QWidget *parent, MainWindow* main_window, Tra
   ProgressHLayout_2->insertWidget(1, pieces_availability);
   // Tracker list
   trackerList = new TrackerList(this);
-#if LIBTORRENT_VERSION_MINOR > 14
-  trackerUpButton->setVisible(false);
-  trackerDownButton->setVisible(false);
-#else
   connect(trackerUpButton, SIGNAL(clicked()), trackerList, SLOT(moveSelectionUp()));
   connect(trackerDownButton, SIGNAL(clicked()), trackerList, SLOT(moveSelectionDown()));
-#endif
   horizontalLayout_trackers->insertWidget(0, trackerList);
   // Peers list
   peersList = new PeerListWidget(this);
@@ -131,7 +125,6 @@ PropertiesWidget::PropertiesWidget(QWidget *parent, MainWindow* main_window, Tra
 
 PropertiesWidget::~PropertiesWidget() {
   qDebug() << Q_FUNC_INFO << "ENTER";
-  saveFilesListState();
   delete refreshTimer;
   delete trackerList;
   delete peersList;
@@ -276,16 +269,6 @@ void PropertiesWidget::loadTorrentInfos(const QTorrentHandle &_h) {
   loadDynamicData();
 }
 
-void PropertiesWidget::loadFilesListState() {
-  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
-  filesList->header()->restoreState(settings.value("TorrentProperties/FilesListState").toByteArray());
-}
-
-void PropertiesWidget::saveFilesListState() {
-  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
-  settings.setValue("TorrentProperties/FilesListState", filesList->header()->saveState());
-}
-
 void PropertiesWidget::readSettings() {
   QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   // Restore splitter sizes
@@ -296,6 +279,9 @@ void PropertiesWidget::readSettings() {
     QSplitter *hSplitter = static_cast<QSplitter*>(parentWidget());
     hSplitter->setSizes(slideSizes);
   }
+  if (!filesList->header()->restoreState(settings.value("TorrentProperties/FilesListState").toByteArray())) {
+    filesList->header()->resizeSection(0, 400); //Default
+  }
   const int current_tab = settings.value("TorrentProperties/CurrentTab", -1).toInt();
   m_tabBar->setCurrentIndex(current_tab);
   if(!settings.value("TorrentProperties/Visible", false).toBool()) {
@@ -317,6 +303,7 @@ void PropertiesWidget::saveSettings() {
   if(sizes.size() == 2) {
     settings.setValue(QString::fromUtf8("TorrentProperties/SplitterSizes"), QVariant(QString::number(sizes.first())+','+QString::number(sizes.last())));
   }
+  settings.setValue("TorrentProperties/FilesListState", filesList->header()->saveState());
   // Remember current tab
   settings.setValue("TorrentProperties/CurrentTab", m_tabBar->currentIndex());
 }
@@ -373,7 +360,7 @@ void PropertiesWidget::loadDynamicData() {
           std::vector<int> avail;
           h.piece_availability(avail);
           pieces_availability->setAvailability(avail);
-          avail_average_lbl->setText(QString::number(h.status().distributed_copies, 'f', 3));
+          avail_average_lbl->setText(QString::number(h.distributed_copies(), 'f', 3));
         } else {
           showPiecesAvailability(false);
         }
@@ -402,10 +389,12 @@ void PropertiesWidget::loadDynamicData() {
       // Files progress
       if(h.is_valid() && h.has_metadata()) {
         qDebug("Updating priorities in files tab");
+        filesList->setUpdatesEnabled(false);
         std::vector<size_type> fp;
         h.file_progress(fp);
         PropListModel->model()->updateFilesPriorities(h.file_priorities());
         PropListModel->model()->updateFilesProgress(fp);
+        filesList->setUpdatesEnabled(true);
       }
     }
   } catch(invalid_handle e) {}
@@ -474,7 +463,11 @@ void PropertiesWidget::displayFilesListMenu(const QPoint&){
     myFilesLlistMenu.addSeparator();
   }
   QMenu subMenu;
+#if LIBTORRENT_VERSION_MINOR > 15
+  if(!h.status(0x0).is_seeding) {
+#else
   if(!static_cast<torrent_handle>(h).is_seed()) {
+#endif
     subMenu.setTitle(tr("Priority"));
     subMenu.addAction(actionNot_downloaded);
     subMenu.addAction(actionNormal);
