@@ -39,12 +39,18 @@
 #include <QRegExp>
 #include <QTimer>
 
+#ifndef QT_NO_OPENSSL
+#include <QSslSocket>
+#else
+#include <QTcpSocket>
+#endif
+
 using namespace libtorrent;
 
 const int BAN_TIME = 3600000; // 1 hour
 
 class UnbanTimer: public QTimer {
-  public:
+public:
   UnbanTimer(QObject *parent, QString peer_ip): QTimer(parent), peer_ip(peer_ip){
     setSingleShot(true);
     setInterval(BAN_TIME);
@@ -87,7 +93,13 @@ HttpServer::HttpServer(int msec, QObject* parent) : QTcpServer(parent) {
   username = pref.getWebUiUsername().toLocal8Bit();
   password_ha1 = pref.getWebUiPassword().toLocal8Bit();
   m_localAuth = pref.isWebUiLocalAuthEnabled();
-  connect(this, SIGNAL(newConnection()), this, SLOT(newHttpConnection()));
+#ifndef QT_NO_OPENSSL
+  m_https = pref.isWebUiHttpsEnabled();
+  if (m_https) {
+    m_certificate = QSslCertificate(pref.getWebUiHttpsCertificate());
+    m_key = QSslKey(pref.getWebUiHttpsKey(), QSsl::Rsa);
+  }
+#endif
   manager = new EventManager(this);
   //add torrents
   std::vector<torrent_handle> torrents = QBtSession::instance()->getTorrents();
@@ -129,6 +141,10 @@ HttpServer::HttpServer(int msec, QObject* parent) : QTcpServer(parent) {
   a = tr("The Web UI password must be at least 3 characters long.");
   a = tr("Save");
   a = tr("qBittorrent client is not reachable");
+  a = tr("HTTP Server");
+  a = tr("The following parameters are supported:");
+  a = tr("Torrent path");
+  a = tr("Torrent name");
 }
 
 HttpServer::~HttpServer()
@@ -137,24 +153,60 @@ HttpServer::~HttpServer()
   delete manager;
 }
 
-void HttpServer::newHttpConnection()
+#ifndef QT_NO_OPENSSL
+void HttpServer::enableHttps(const QSslCertificate &certificate, const QSslKey &key)
 {
-  QTcpSocket *socket;
-  while((socket = nextPendingConnection()))
-  {
-    HttpConnection *connection = new HttpConnection(socket, this);
-    //connect connection to QBtSession::instance()
-    connect(connection, SIGNAL(UrlReadyToBeDownloaded(QString)), QBtSession::instance(), SLOT(downloadUrlAndSkipDialog(QString)));
-    connect(connection, SIGNAL(MagnetReadyToBeDownloaded(QString)), QBtSession::instance(), SLOT(addMagnetSkipAddDlg(QString)));
-    connect(connection, SIGNAL(torrentReadyToBeDownloaded(QString, bool, QString, bool)), QBtSession::instance(), SLOT(addTorrent(QString, bool, QString, bool)));
-    connect(connection, SIGNAL(deleteTorrent(QString, bool)), QBtSession::instance(), SLOT(deleteTorrent(QString, bool)));
-    connect(connection, SIGNAL(pauseTorrent(QString)), QBtSession::instance(), SLOT(pauseTorrent(QString)));
-    connect(connection, SIGNAL(resumeTorrent(QString)), QBtSession::instance(), SLOT(resumeTorrent(QString)));
-    connect(connection, SIGNAL(pauseAllTorrents()), QBtSession::instance(), SLOT(pauseAllTorrents()));
-    connect(connection, SIGNAL(resumeAllTorrents()), QBtSession::instance(), SLOT(resumeAllTorrents()));
+  m_certificate = certificate;
+  m_key = key;
+  m_https = true;
+}
+
+void HttpServer::disableHttps()
+{
+  m_https = false;
+  m_certificate.clear();
+  m_key.clear();
+}
+#endif
+
+void HttpServer::incomingConnection(int socketDescriptor)
+{
+  QTcpSocket *serverSocket;
+#ifndef QT_NO_OPENSSL
+  if (m_https)
+    serverSocket = new QSslSocket(this);
+  else
+#endif
+    serverSocket = new QTcpSocket(this);
+  if (serverSocket->setSocketDescriptor(socketDescriptor)) {
+#ifndef QT_NO_OPENSSL
+    if (m_https) {
+      static_cast<QSslSocket*>(serverSocket)->setProtocol(QSsl::AnyProtocol);
+      static_cast<QSslSocket*>(serverSocket)->setPrivateKey(m_key);
+      static_cast<QSslSocket*>(serverSocket)->setLocalCertificate(m_certificate);
+      static_cast<QSslSocket*>(serverSocket)->startServerEncryption();
+    }
+#endif
+    handleNewConnection(serverSocket);
+  } else {
+    serverSocket->deleteLater();
   }
 }
 
+void HttpServer::handleNewConnection(QTcpSocket *socket)
+{
+  HttpConnection *connection = new HttpConnection(socket, this);
+  //connect connection to QBtSession::instance()
+  connect(connection, SIGNAL(UrlReadyToBeDownloaded(QString)), QBtSession::instance(), SLOT(downloadUrlAndSkipDialog(QString)));
+  connect(connection, SIGNAL(MagnetReadyToBeDownloaded(QString)), QBtSession::instance(), SLOT(addMagnetSkipAddDlg(QString)));
+  connect(connection, SIGNAL(torrentReadyToBeDownloaded(QString, bool, QString, bool)), QBtSession::instance(), SLOT(addTorrent(QString, bool, QString, bool)));
+  connect(connection, SIGNAL(deleteTorrent(QString, bool)), QBtSession::instance(), SLOT(deleteTorrent(QString, bool)));
+  connect(connection, SIGNAL(pauseTorrent(QString)), QBtSession::instance(), SLOT(pauseTorrent(QString)));
+  connect(connection, SIGNAL(resumeTorrent(QString)), QBtSession::instance(), SLOT(resumeTorrent(QString)));
+  connect(connection, SIGNAL(pauseAllTorrents()), QBtSession::instance(), SLOT(pauseAllTorrents()));
+  connect(connection, SIGNAL(resumeAllTorrents()), QBtSession::instance(), SLOT(resumeAllTorrents()));
+}
+
 void HttpServer::onTimer() {
   std::vector<torrent_handle> torrents = QBtSession::instance()->getTorrents();
   std::vector<torrent_handle>::iterator torrentIT;
