@@ -23,7 +23,7 @@ initializeWindows = function(){
 		new Event(e).stop();
 		new MochaUI.Window({
 			id: 'downloadPage',
-			title: "_(Download from URL)",
+			title: "_(Download from urls)",
 			loadMethod: 'iframe',
 			contentURL:'download.html',
 			scrollbars: true,
@@ -150,11 +150,25 @@ initializeWindows = function(){
 	
 	deleteFN = function() {
 		var h = myTable.selectedIds();
-		if(h.length && confirm('_(Are you sure you want to delete the selected torrents from the transfer list?)')) {
+		/*if(h.length && confirm('_(Are you sure you want to delete the selected torrents from the transfer list?)')) {
 			h.each(function(item, index){
 				new Request({url: '/command/delete', method: 'post', data: {hash: item}}).send();
 			});
-		}	
+		}*/
+		if(h.length) {
+                	new MochaUI.Window({
+				id: 'confirmDeletionPage',
+				title: "_(Deletion confirmation - qBittorrent)",
+				loadMethod: 'iframe',
+				contentURL:'confirmdeletion.html?hashes='+JSON.encode(h),
+				scrollbars: false,
+				resizable: false,
+				maximizable: false,
+				padding: 10,
+				width: 424,
+				height: 140
+			});
+                }
 	};
 
 	addClickEvent('delete', function(e){
@@ -162,21 +176,6 @@ initializeWindows = function(){
 		deleteFN();
 	});
 	
-	deleteHDFN = function() {
-		var h = myTable.selectedIds();
-                if(h.length && confirm('_(Are you sure you want to delete the selected torrents from the transfer list and hard disk?)')) {
-                        h.each(function(item, index){
-                                new Request({url: '/command/deletePerm', method: 'post', data: {hash: item}}).send();
-                        });
-                }
-	};
-	
-
-	addClickEvent('deletePerm', function(e){
-                new Event(e).stop();
-		deleteHDFN();
-        });
-	
 	pauseFN = function() {
 		var h = myTable.selectedIds();
 		if(h.length){
@@ -204,7 +203,7 @@ initializeWindows = function(){
 		}
 	};
 
-	['pause','resume','decreasePrio','increasePrio', 'topPrio', 'bottomPrio', 'recheck'].each(function(item) {
+	['pause','resume', 'recheck'].each(function(item) {
 		addClickEvent(item, function(e){
 			new Event(e).stop();
 			var h = myTable.selectedIds();
@@ -220,13 +219,18 @@ initializeWindows = function(){
 			new Request({url: '/command/'+item+'all'}).send();
 		});
 	});
+
+	['decreasePrio','increasePrio', 'topPrio', 'bottomPrio'].each(function(item) {
+		addClickEvent(item, function(e){
+			new Event(e).stop();
+			setPriorityFN(item);
+		});
+	});
 	
 	setPriorityFN = function(cmd) {
 		var h = myTable.selectedIds();
-		if(h.length){
-			h.each(function(hash, index){
-				  new Request({url: '/command/'+cmd, method: 'post', data: {hash: hash}}).send();
-				});
+		if(h.length) {
+			new Request({url: '/command/'+cmd, method: 'post', data: {hashes: h.join("|")}}).send();
 		}
 	}
 	
@@ -274,7 +278,8 @@ initializeWindows = function(){
 			loadMethod: 'iframe',
 			contentURL: 'about.html',
 			width: 650,
-			height: 400
+			height: 400,
+			padding: 10
 		});
 	});
 	
